View Source mix gettext_check (gettext_check v0.2.1)
Checks gettext translations for missing translations and raises an error if a translation is missing.
Your files must be saved in the gettext directory structure
e.g. priv/gettext/LOCALE/LC_MESSAGES/DOMAIN.po
GNU gettext .pot, po files are supported.
mix gettext_check [OPTIONS]
Options
--localeor-l- the locale to check- Will be used with priv to find the locale files (e.g.
{priv}/{locale}/LC_MESSAGES) - This can also be set under the config
- Required either here or under the config
- Will be used with priv to find the locale files (e.g.
--privor-p- the path to the priv directory- Defaults to
priv/gettext - This can also be set under the config
- Defaults to